summary refs log tree commit diff
diff options
context:
space:
mode:
authorSergey M․ <dstftw@gmail.com>2017-02-19 01:53:41 +0700
committerSergey M <dstftw@gmail.com>2017-02-19 05:10:08 +0800
commit0a840f584c3f1fedb6957c05587dec697143f2d5 (patch)
tree553633b925896d96c2224f65922a73ff38f6f27a
parent0016b84e16965a07c52946c4672363153e8b18a2 (diff)
downloadyoutube-dl-0a840f584c3f1fedb6957c05587dec697143f2d5.tar.gz
youtube-dl-0a840f584c3f1fedb6957c05587dec697143f2d5.tar.xz
youtube-dl-0a840f584c3f1fedb6957c05587dec697143f2d5.zip
Rename bypass geo restriction options
-rwxr-xr-xyoutube_dl/YoutubeDL.py5
-rw-r--r--youtube_dl/__init__.py4
-rw-r--r--youtube_dl/extractor/common.py8
-rw-r--r--youtube_dl/options.py12
4 files changed, 14 insertions, 15 deletions
diff --git a/youtube_dl/YoutubeDL.py b/youtube_dl/YoutubeDL.py
index 1c04e46c1..68000dea2 100755
--- a/youtube_dl/YoutubeDL.py
+++ b/youtube_dl/YoutubeDL.py
@@ -274,10 +274,9 @@ class YoutubeDL(object):
                        If it returns None, the video is downloaded.
                        match_filter_func in utils.py is one example for this.
     no_color:          Do not emit color codes in output.
-    bypass_geo_restriction:
-                       Bypass geographic restriction via faking X-Forwarded-For
+    geo_bypass:        Bypass geographic restriction via faking X-Forwarded-For
                        HTTP header (experimental)
-    bypass_geo_restriction_as_country:
+    geo_bypass_country:
                        Two-letter ISO 3166-2 country code that will be used for
                        explicit geographic restriction bypassing via faking
                        X-Forwarded-For HTTP header (experimental)
diff --git a/youtube_dl/__init__.py b/youtube_dl/__init__.py
index 94f461a78..f91d29a7b 100644
--- a/youtube_dl/__init__.py
+++ b/youtube_dl/__init__.py
@@ -414,8 +414,8 @@ def _real_main(argv=None):
         'cn_verification_proxy': opts.cn_verification_proxy,
         'geo_verification_proxy': opts.geo_verification_proxy,
         'config_location': opts.config_location,
-        'bypass_geo_restriction': opts.bypass_geo_restriction,
-        'bypass_geo_restriction_as_country': opts.bypass_geo_restriction_as_country,
+        'geo_bypass': opts.geo_bypass,
+        'geo_bypass_country': opts.geo_bypass_country,
     }
 
     with YoutubeDL(ydl_opts) as ydl:
diff --git a/youtube_dl/options.py b/youtube_dl/options.py
index 2e194f6dc..ae3f50754 100644
--- a/youtube_dl/options.py
+++ b/youtube_dl/options.py
@@ -550,16 +550,16 @@ def parseOpts(overrideArguments=None):
             '(maximum possible number of seconds to sleep). Must only be used '
             'along with --min-sleep-interval.'))
     workarounds.add_option(
-        '--bypass-geo',
-        action='store_true', dest='bypass_geo_restriction', default=True,
+        '--geo-bypass',
+        action='store_true', dest='geo_bypass', default=True,
         help='Bypass geographic restriction via faking X-Forwarded-For HTTP header (experimental)')
     workarounds.add_option(
-        '--no-bypass-geo',
-        action='store_false', dest='bypass_geo_restriction', default=True,
+        '--no-geo-bypass',
+        action='store_false', dest='geo_bypass', default=True,
         help='Do not bypass geographic restriction via faking X-Forwarded-For HTTP header (experimental)')
     workarounds.add_option(
-        '--bypass-geo-as-country', metavar='CODE',
-        dest='bypass_geo_restriction_as_country', default=None,
+        '--geo-bypass-country', metavar='CODE',
+        dest='geo_bypass_country', default=None,
         help='Force bypass geographic restriction with explicitly provided two-letter ISO 3166-2 country code (experimental)')
 
     verbosity = optparse.OptionGroup(parser, 'Verbosity / Simulation Options')
diff --git a/youtube_dl/extractor/common.py b/youtube_dl/extractor/common.py
index c1f7f28a0..6eb6a25b8 100644
--- a/youtube_dl/extractor/common.py
+++ b/youtube_dl/extractor/common.py
@@ -326,7 +326,7 @@ class InfoExtractor(object):
     _BYPASS_GEO attribute may be set to False in order to disable
     geo restriction bypass mechanisms for a particular extractor.
     Though it won't disable explicit geo restriction bypass based on
     country code provided with bypass_geo_restriction_as_country.
 
     Finally, the _WORKING attribute should be set to False for broken IEs
     in order to warn the users and skip the tests.
@@ -371,7 +371,7 @@ class InfoExtractor(object):
     def initialize(self):
         """Initializes an instance (authentication, etc)."""
         if not self._x_forwarded_for_ip:
-            country_code = self._downloader.params.get('bypass_geo_restriction_as_country', None)
+            country_code = self._downloader.params.get('geo_bypass_country', None)
             if country_code:
                 self._x_forwarded_for_ip = GeoUtils.random_ipv4(country_code)
         if not self._ready:
@@ -389,9 +389,9 @@ class InfoExtractor(object):
                         ie_result['__x_forwarded_for_ip'] = self._x_forwarded_for_ip
                     return ie_result
                 except GeoRestrictedError as e:
-                    if (not self._downloader.params.get('bypass_geo_restriction_as_country', None) and
+                    if (not self._downloader.params.get('geo_bypass_country', None) and
                             self._BYPASS_GEO and
-                            self._downloader.params.get('bypass_geo_restriction', True) and
+                            self._downloader.params.get('geo_bypass', True) and
                             not self._x_forwarded_for_ip and
                             e.countries):
                         self._x_forwarded_for_ip = GeoUtils.random_ipv4(random.choice(e.countries))
@@ -326,7 +326,7 @@ class InfoExtractor(object):
     geo restriction bypass mechanisms for a particular extractor.
     Though it won't disable explicit geo restriction bypass based on
-    country code provided with bypass_geo_restriction_as_country.
+    country code provided with geo_bypass_country.
 
     Finally, the _WORKING attribute should be set to False for broken IEs